@@ -116,7 +116,7 @@ gconf_bookmarks_update_menu (GtkWidget *menu)
 		g_signal_connect (menuitem, "activate",
 				  G_CALLBACK (gconf_bookmarks_bookmark_activated), window);
 		g_object_set_data_full (G_OBJECT (menuitem), "gconf-key", g_strdup (tmp->data), g_free);
-		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem), gtk_image_new_from_stock (GCONF_STOCK_BOOKMARK,
+		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem), gtk_image_new_from_stock (STOCK_BOOKMARK,
 													 GTK_ICON_SIZE_MENU));
 		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 		gtk_widget_show_all (menuitem);
@@ -215,12 +215,13 @@ gconf_bookmarks_hook_up_menu (GConfEditorWindow *window,
                 err = NULL;
                 value = gconf_client_get (client, "/desktop/gnome/interface/menus_have_icons", &err);
 
-                if (err != NULL || value->type != GCONF_VALUE_BOOL)
+                if (err != NULL || value == NULL || value->type != GCONF_VALUE_BOOL)
                         return;
 
                 have_icons = gconf_value_get_bool (value);
-
                 gconf_bookmarks_set_have_icons (menu, have_icons);
+
+                gconf_value_free (value);
         }
 
 	if ( ! gconf_client_key_is_writable (client, "/apps/gconf-editor/bookmarks", NULL)) {
